==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultHSBChooserPanel__24RadioStateListener.h <==
// class javax.swing.colorchooser.DefaultHSBChooserPanel$RadioStateListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f06ef292287f1a06 javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener_H_
#define _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vmethods	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtable	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtype	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$method$_init$6dfecddff5585109(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object *);

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vmethods	javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$refs {
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_refs	javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_nonrefs	javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object {
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtype _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener_H_ */

==> jc-1.4.6.tar.gz: javax/swing/colorchooser/DefaultHSBChooserPanel__24RadioStateListener.h <==
// class javax.swing.colorchooser.DefaultHSBChooserPanel$RadioStateListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 429da93b329f319 javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener_H_
#define _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vmethods	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtable	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtype	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$method$_init$6dfecddff5585109(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vmethods	javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$refs {
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_refs	javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$sub_nonrefs	javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$object {
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$vtype _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24RadioStateListener_H_ */
